evict_underpriced_transactions_for_t1

Function evict_underpriced_transactions_for_t1 

fn evict_underpriced_transactions_for_t1<Pool>(pool: &Pool) -> usize
where Pool: TransactionPool,
Removes transactions with max_fee_per_gas below the T1 base fee from the pool.

This is a one-time cleanup performed when the T0 → T1 hardfork transition is detected. After T1 activation, transactions with max_fee_per_gas < 20 billion attodollars are never includable and should be evicted from the pool.

Note

This function is temporary and will be removed after T1 is activated on mainnet.