pub fn handle_reorg<F>(
old_chain: Arc<Chain<TempoPrimitives>>,
new_chain: Arc<Chain<TempoPrimitives>>,
is_in_pool: F,
) -> (Vec<TempoPooledTransaction>, HashSet<AASequenceId>)Expand description
Handles a reorg event by identifying orphaned AA 2D transactions from the old chain that are not in the new chain.
Returns:
- Orphaned transactions to re-inject
- Affected sequence IDs whose nonce state needs to be reset from the new tip’s state